@@ -3,7 +3,8 @@ context("Result rownames")
 test_that("when no row-names in the input - numbers are added", {
   X <- matrix(rnorm(100), nrow=10)
   Y <- matrix(rnorm(100), nrow=10)
-  grp <- sample(c(1,0), 10, replace=TRUE)
+  grp  <- sample(c(1,0), 10, replace=TRUE)
+  time <- 1:10
   rnames <- as.character(1:nrow(X))
   expect_equal(rownames(row_t_onesample(x=X)), rnames)
   expect_equal(rownames(row_t_equalvar(x=X, y=Y)), rnames)
@@ -22,13 +23,15 @@ test_that("when no row-names in the input - numbers are added", {
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
+  expect_equal(rownames(row_cosinor(x=X, t=time)), rnames)
 })
 
 
 test_that("when X doesn't have rownames - names from Y or groups are not used", {
   X <- matrix(rnorm(100), nrow=10)
   Y <- matrix(rnorm(100), nrow=10)
-  grp <- sample(c(1,0), 10, replace=TRUE)
+  grp  <- sample(c(1,0), 10, replace=TRUE)
+  time <- 1:10
   rownames(Y) <- LETTERS[1:10]
   names(grp) <- LETTERS[1:10]
   rnames <- as.character(1:nrow(X))
@@ -49,6 +52,7 @@ test_that("when X doesn't have rownames - names from Y or groups are not used",
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
+  expect_equal(rownames(row_cosinor(x=X, t=time)), rnames)
 })
 
 
@@ -57,7 +61,8 @@ test_that("when row-names are specified - they are preserved", {
   X <- matrix(rnorm(100), nrow=10)
   rownames(X) <- LETTERS[1:10]
   Y <- matrix(rnorm(100), nrow=10)
-  grp <- sample(c(1,0), 10, replace=TRUE)
+  grp  <- sample(c(1,0), 10, replace=TRUE)
+  time <- 1:10
   rnames <- rownames(X)
   expect_equal(rownames(row_t_onesample(x=X)), rnames)
   expect_equal(rownames(row_t_equalvar(x=X, y=Y)), rnames)
@@ -76,6 +81,7 @@ test_that("when row-names are specified - they are preserved", {
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
+  expect_equal(rownames(row_cosinor(x=X, t=time)), rnames)
   # data.frame case
   X <- as.data.frame(X)
   Y <- as.data.frame(Y)
@@ -97,13 +103,15 @@ test_that("when row-names are specified - they are preserved", {
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
+  expect_equal(rownames(row_cosinor(x=X, t=time)), rnames)
 })
 
 
 test_that("when row-names are duplicated - they are modified to be unique", {
   X <- matrix(rnorm(100), nrow=10)
   Y <- matrix(rnorm(100), nrow=10)
-  grp <- sample(c(1,0), 10, replace=TRUE)
+  grp  <- sample(c(1,0), 10, replace=TRUE)
+  time <- 1:10
   rownames(X) <- c(rep("A",5), rep("B", 5))
   rnames <- make.unique(rownames(X))
   expect_equal(rownames(row_t_onesample(x=X)), rnames)
@@ -123,5 +131,6 @@ test_that("when row-names are duplicated - they are modified to be unique", {
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
+  expect_equal(rownames(row_cosinor(x=X, t=time)), rnames)
 })
 
